@@ -583,7 +583,7 @@ QUrl Navigator::homeURL()
   // We have to reparse the configuration here in order to get a
   // language-specific StartUrl, e.g. "StartUrl[de]".
   cfg->reparseConfiguration();
-  mHomeUrl = QUrl(cfg->group("General").readPathEntry( "StartUrl", QStringLiteral("khelpcenter:home") ));
+  mHomeUrl = QUrl(cfg->group(QStringLiteral("General")).readPathEntry( "StartUrl", QStringLiteral("khelpcenter:home") ));
   return mHomeUrl;
 }
 
